//
//  THSMenu.java
//  treehousestudio
//
//  Created by Maxwell Planck on Tue Jan 07 2003.
//  Copyright (c) 2003 __MyCompanyName__. All rights reserved.
//

import java.util.*;
import java.awt.*;

public class THSMenu extends THSPanel {

    public Vector menuitems;
    private final int space = 8;
    private boolean isSelected;
    public THSGeneralMenuItem currMItem;
    
    public THSMenu(String s, int x, int y, int w, int h) {
        super(s, x, y, w, h);
        isSelected = false;
        menuitems = new Vector();
    }

    /**
     * These methods handle whether or not this menu is selected
     */
    public void setIsSelected() {
        isSelected = true;
    }

    public void reset() {
        isSelected = false;
    }
    
    /**
     * This method adds the specified menuitem to the menu in the order it was called in the code
     */
    public void addMenuItem(THSGeneralMenuItem mi) {
        if (mi != null) {
            menuitems.addElement(mi);
        } else {
            throw new RuntimeException();
        }
    }

    /**
     * This method resets the menuitems so that this particular menu doesn't have any items
     */
    public void resetMenu() {
        menuitems = new Vector();
    }


    /**
     * This method draws a menu that is not unfolded
     */
    public void draw(Graphics gi) {
        if (!isSelected) {
            gi.setColor(Color.black);
            this.placeString(gi);
            currMItem = null;
        } else {
            // highlight
            gi.setColor(Color.black);
            this.fill(gi);
            gi.setColor(Color.white);
            this.placeString(gi);
            unfold(gi);
        }
    }

    public void mouseDown(Event ev, int mx, int my) {
        System.out.println("You have selected the " + cs + " menu");
        setIsSelected();
    }
    
    public void mouseDrag(Event ev, int mx, int my) {
        setIsSelected();
    }

    public void mouseUp(Event ev, int x, int y) {
        if (currMItem != null) {
            currMItem.actuate();
        }
        reset();
    }

    /**
     * This method draws the menu.  Since it is a drawing method, it takes in the Graphics object
     * that handles all rendering within the Applet.  This method also returns the current menuitem selected
     */
    private void unfold(Graphics gi) {

        int leading = 4;
        
        FontMetrics fm = gi.getFontMetrics();
        int spaceperitem = fm.getHeight() + leading;
        int fd = fm.getDescent();
        int fh = fm.getHeight();

        int maxw = 0, w, i;
        for(i=0;i < menuitems.size();i++) {
            String s = ((THSGeneralMenuItem) menuitems.elementAt(i)).getString();
            w= fm.stringWidth(s);
            if (w > maxw) maxw = w;
        }

        // Draw menu box with white interior and black border
        gi.setColor(Color.white);
        gi.fillRect(cx, ch, maxw+space*2, menuitems.size()*spaceperitem);
        gi.setColor(Color.black);
        gi.drawRect(cx, ch, maxw+space*2, menuitems.size()*spaceperitem);

        ((Graphics2D) gi).setRenderingHint(RenderingHints.KEY_TEXT_ANTIALIASING, RenderingHints.VALUE_TEXT_ANTIALIAS_ON);

        int y;
        for(i=0, y=ch; i < menuitems.size(); i++, y+=spaceperitem) {
            THSGeneralMenuItem currMI = (THSGeneralMenuItem) menuitems.elementAt(i);
            String name = currMI.getString();
            if (name.equals("-")) {
                gi.setColor(Color.lightGray);
                gi.drawLine(cx+3,y+spaceperitem/2,cx+maxw+space*2-3,y+spaceperitem/2);
                gi.setColor(Color.black);
            } else {
                gi.drawString(name, cx+space, y-fd+spaceperitem-1);
                if (inrectp(cx, y, maxw+2*space, spaceperitem)) {
                    gi.setColor(Color.black);
                    gi.fillRect(cx+1,y+1,maxw+space*2-1,spaceperitem);
                    gi.setColor(Color.white);
                    gi.drawString(name,cx+space,y-fd+spaceperitem-1);
                    gi.setColor(Color.black);
                    currMItem = currMI;
                }
            }
        }
    }

    /**
     * Returns true if the mouse is currently within the specified rectangle- characterized by top left
     * coordinates and a width and height.  The mouse position is retrieved from the Applet class.
     */
    public boolean inrectp(int x, int y, int w, int h)
    {
        int[] mPos = Treehousestudio.reportMousePos();
        int mx = mPos[0]; int my = mPos[1];
        int s = 0;
        return (mx>x-s&&mx<x+w+s&&my>y-s&&my<y+h+s);
    }

    public boolean keyDown(Event ev, int k) {
        return false;
    }

    public void message(String f, Object o) {};
}
