//
//  menuitem.java
//  Treehousestudio
//
//  Created by Maxwell Planck on Tue Jan 07 2003.
//  Copyright (c) 2003 __MyCompanyName__. All rights reserved.
//

import java.awt.*;
import java.applet.*;
import PaintCanvas;

/**
 * HOW TO ADD A MENU ITEM
 *
 * To make a new menu item add a static integer to the list below with the name of your menuitem.  Assign
 * it a unique integer value (it doesn't matter what it is).  Add a case statement to the makeMenuItem()
 * method with the unique static integer variable as the case integer.  Have it return a newly instantiated
 * menu item that you will add at the end of this class.  To make a menu item, have it extend the abstract
 * class THSGeneralMenuItem.  Make sure to instantiate the super class with super("<name of menu item>") and to
 * specify an action for the actuate() method.  The <name of menu item> string specifies how the option appears
 * in the menu.  Note that you can name your menu item class any way you would like but for consistency, I
 * recommend naming it "<Name of Menu Item>MenuItem" (all capitals).
 *
 * Keep in mind that the makeMenuItem() method needs to be passed the objects on which the menu items act, so
 * if you need to add something that you would like to actuate upon with the menu item.  For now, I believe all
 * menu items should only effect the main canvas area (mainhb), the Graphics object upon which everything is
 * drawn, and the Applet itself.  Refer to the menu items already written as a reference.
 *
 * Once you have done all of this, add the menu item to the menu of your choice by following the directions in
 * the Treehousestudio class.
 */

public class THSMenuItems {

    /***********************************************************************************
    ************************************************************************************
    ************************************************************************************
    **
    ** Add menu item stuff after this point.  Refer to the HOW TO guide above for adding
    ** a menu item.
    **
    ************************************************************************************
    ************************************************************************************
    ************************************************************************************/

    // These static final variables are used to reference the type of menu item to be instantiated
    // when the makeMenuItem() method is called.
    public final static int COPY = 1;
    public final static int CUT = 2;
    public final static int PASTE = 3;
    public final static int SPACER = 4;
    public final static int UNDO = 5;
    public final static int SHOWCLIPBOARD = 6;
    public final static int SAVE = 7;
    public final static int OPEN = 8;

    public final static int MAKEBRIGHTNESS5 = 9;
    /**
     * This method produces a menu item given a specific name.  It also takes in
     * the arguments that a menu item might use.  If the name specified is not a valid
     * menu item, null is returned.
     */
    public static THSGeneralMenuItem makeMenuItem(int name, PaintCanvas mainhb, Graphics g, Applet app) {
        switch (name) {
            case COPY:
                return new CopyMenuItem();
            case CUT:
                return new CutMenuItem();
            case PASTE:
                return new PasteMenuItem();
            case SPACER:
                return new Spacer();
            case UNDO:
                return new UndoMenuItem(mainhb);
            case SHOWCLIPBOARD:
                return new ShowClipboardMenuItem();
            case SAVE:
                return new SaveMenuItem(mainhb, g, app);
            case OPEN:
                return new OpenMenuItem();
            case MAKEBRIGHTNESS5:
                return new MakeBrightness5();
            default:
                return null;
        }
    }
    
}

/***********************************************************************************
************************************************************************************
************************************************************************************
**
** All of the following menu items are original and should not be modified unless you
** want to mess with core functionality.
**
************************************************************************************
************************************************************************************
************************************************************************************/

 // All the menu items right now are not completed (THIS NEEDS TO CHANGE)

/**
 * This unique type of menu item can be used to create separation within the menu item.  For instance, look
 * at the "Edit" menu and see the dividing line between the Undo action and the Cut action.  There is a Spacer
 * menu item between the two.
 */
class Spacer extends THSGeneralMenuItem {

    public Spacer() {
        super("-");
    }

    public void actuate() {
        // do nothing
        return;
    }
}

class OpenMenuItem extends THSGeneralMenuItem{

    public OpenMenuItem() {
        super("Open");
    }

    public void actuate() {
        // do nothing
        return;
    }

}

class SaveMenuItem extends THSGeneralMenuItem {

    PaintCanvas mainhb;
    Graphics g;
    Applet app;

    public SaveMenuItem(PaintCanvas THSPanel, Graphics g, Applet app) {
        super("Save");
        mainhb = THSPanel;
        this.g = g;
        this.app = app;
    }

    public void actuate() {
        //    mainhb.dosave(g, app);
    }
}

class CopyMenuItem extends THSGeneralMenuItem {

    public CopyMenuItem() {
        super("Copy");
    }

    public void actuate() {
        // do nothing
        return;
    }

}

class CutMenuItem extends THSGeneralMenuItem {

    public CutMenuItem() {
        super("Cut");
    }

    public void actuate() {
        // do nothing
        return;
    }

}


class PasteMenuItem extends THSGeneralMenuItem {

    public PasteMenuItem() {
        super("Paste");
    }

    public void actuate() {
        // do nothing
        return;
    }

}

class ShowClipboardMenuItem extends THSGeneralMenuItem {

    public ShowClipboardMenuItem() {
        super("Show Clipboard");
    }

    public void actuate() {
        // do nothing
        return;
    }

}

class UndoMenuItem extends THSGeneralMenuItem {

    PaintCanvas mainhb;

    public UndoMenuItem(PaintCanvas THSPanel) {
        super("Undo");

        mainhb = THSPanel;
    }

    public void actuate() {
        mainhb.doundo();
    }

}

class MakeBrightness5 extends THSGeneralMenuItem {

    public MakeBrightness5() {
        super("Make Brightness 5");
    }
    
    public void actuate() {
        System.out.println("Making brightness 5");
    }
    
}